@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2011  Tom Cato Amundsen
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -293,7 +293,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             ("lilypond-book", _("Lilypond-book:"),
              osutils.find_progs(("lilypond-book", "lilypond-book.py"))),
             ("latex", "Latex:", osutils.find_progs(("latex",))),
-            ("text-editor", "Text editor:", osutils.find_progs(("sensible-editor", "gvim", "gedit", "emacs", "notepad.exe"))),
+            ("text-editor", _("Text editor:"), osutils.find_progs(("sensible-editor", "gvim", "gedit", "emacs", "notepad.exe"))),
             ):
             liststore = gtk.ListStore(gobject.TYPE_STRING)
             for p in bins:
@@ -622,18 +622,20 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         except osutils.BinaryBaseException, e:
             solfege.win.display_error_message2(e.msg1, e.msg2)
     def popup_alsa_connection_list(self, widget):
-        menu = gtk.Menu()
-        for clientid, portid, clientname, portname, labeltext in soundcard.alsa_sequencer.get_connection_list():
-            item = gtk.MenuItem(labeltext)
-            item.set_data('client-port-id', (clientid, portid))
-            menu.append(item)
-            def ff(widget, clientid, portid):
-                self.g_alsa_device.set_label(widget.get_child().get_text())
-                self.m_gui_client_port = (clientid, portid)
-                self.g_alsa_radio.set_active(True)
-            item.connect('activate', ff, clientid, portid)
-        menu.show_all()
-        menu.popup(None, None, None, 1, 0)
+        connection_list = soundcard.alsa_sequencer.get_connection_list()
+        if connection_list:
+            menu = gtk.Menu()
+            for clientid, portid, clientname, portname, labeltext in connection_list:
+                item = gtk.MenuItem(labeltext)
+                item.set_data('client-port-id', (clientid, portid))
+                menu.append(item)
+                def ff(widget, clientid, portid):
+                    self.g_alsa_device.set_label(widget.get_child().get_text())
+                    self.m_gui_client_port = (clientid, portid)
+                    self.g_alsa_radio.set_active(True)
+                item.connect('activate', ff, clientid, portid)
+            menu.show_all()
+            menu.popup(None, None, None, 1, 0)
     def create_linux_sound_page(self):
         it, page_vbox = self.new_page_box(None, _("Sound Setup"))
         #############
@@ -644,6 +646,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         page_vbox.pack_start(self.g_fakesynth_radio, False)
 
         ### ALSA
+        self.m_gui_client_port = False
         hbox = gu.bHBox(page_vbox, False)
         self.g_alsa_radio = gu.RadioButton(self.g_fakesynth_radio,
               _("Use ALSA _device"), None)
@@ -660,8 +663,11 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
                     self.m_gui_client_port = v[0:2]
                     break
             else:
-                self.m_gui_client_port = connections[-1][0:2]
-                self.g_alsa_device.set_label(connections[-1][-1])
+                if connections:
+                    self.m_gui_client_port = connections[-1][0:2]
+                    self.g_alsa_device.set_label(connections[-1][-1])
+                else:
+                    self.g_alsa_device.set_label("")
         else:
             self.g_alsa_device.set_sensitive(False)
             self.g_alsa_radio.set_sensitive(False)
@@ -812,11 +818,14 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
                 solfege.app.display_sound_init_error_message(e)
                 return -1
         elif solfege.soundcard.alsa_sequencer and self.g_alsa_radio.get_active():
-            try:
-                soundcard.initialise_alsa_sequencer(self.m_gui_client_port)
-            except solfege.soundcard.alsa_sequencer.alsaseq.SequencerError, e:
-                logging.debug("initialise_alsa_sequencer(%s) failed: %s", self.m_gui_client_port, str(e))
-                solfege.app.display_sound_init_error_message(e)
+            if self.m_gui_client_port:
+                try:
+                    soundcard.initialise_alsa_sequencer(self.m_gui_client_port)
+                except solfege.soundcard.alsa_sequencer.alsaseq.SequencerError, e:
+                    logging.debug("initialise_alsa_sequencer(%s) failed: %s", self.m_gui_client_port, str(e))
+                    solfege.app.display_sound_init_error_message(e)
+                    return -1
+            else:
                 return -1
         else: # no sound
             assert self.g_fakesynth_radio.get_active()
