@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007, 2008  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007, 2008, 2011  Tom Cato Amundsen
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,8 +28,10 @@ soundcard.end_export()
 
 """
 import atexit
+import subprocess
 import sys
 import os
+import solfege
 from solfege.soundcard.soundcardexceptions import SoundInitException
 from solfege.soundcard.exporter import MidiExporter
 from solfege import cfg
@@ -72,13 +74,23 @@ def play_mediafile(typeid, filename):
             if '%s' in s:
                 args[i] = args[i] % os.path.abspath(filename)
                 found = True
+                break
+        # Remove left over %s, just in case the user entered more than
+        # one in the preferences window.
+        args = [x for x in args if x != '%s']
         if not found:
             args.append(os.path.abspath(filename))
         if _mediaplayer and _mediaplayer.poll() == None:
             _mediaplayer.kill()
             _mediaplaer  = None
         try:
-            _mediaplayer = osutils.Popen(args=args)
+            if sys.platform == 'win32':
+                info = subprocess.STARTUPINFO()
+                info.dwFlags = 1
+                info.wShowWindow = 0
+                _mediaplayer = osutils.Popen(args=args, startupinfo=info)
+            else:
+                _mediaplayer = osutils.Popen(args=args)
         except OSError, e:
             raise osutils.BinaryForMediaPlayerException(typeid,
                 cfg.get_string("sound/%s_player" % typeid), e)
@@ -87,20 +99,31 @@ def play_mediafile(typeid, filename):
 def initialise_winsynth(synthnum, verbose_init=0):
     from solfege.soundcard import winsynth
     global synth
+    solfege.mpd.track.set_patch_delay = cfg.get_int("app/set_patch_delay")
     synth = winsynth.WinSynth(synthnum, verbose_init)
 
+def initialise_alsa_sequencer(port, verbose_init=0):
+    """
+    This function should only be called if the pyalsa module is available.
+    """
+    global synth
+    from solfege.soundcard import alsa_sequencer
+    solfege.mpd.track.set_patch_delay = cfg.get_int("app/set_patch_delay")
+    synth = alsa_sequencer.AlsaSequencer(port, verbose_init)
 
-def initialise_external_midiplayer(cmdline, verbose_init=0):
+
+def initialise_external_midiplayer(verbose_init=0):
     global synth
     import solfege.soundcard.midifilesynth
-    synth = solfege.soundcard.midifilesynth.MidiFileSynth(cmdline, verbose_init)
+    solfege.mpd.track.set_patch_delay = cfg.get_int("app/set_patch_delay")
+    synth = solfege.soundcard.midifilesynth.MidiFileSynth(verbose_init)
 
 
 def initialise_devicefile(devicefile, devicenum=0, verbose_init=0):
     global synth
     if devicefile == '/dev/sequencer2' or devicefile == '/dev/music':
         import solfege.soundcard.oss_sequencer2
-        synth = solfege.soundcard.oss_sequencer2.OSSSequencer2Synth(devicefile, devicenum, 
+        synth = solfege.soundcard.oss_sequencer2.OSSSequencer2Synth(devicefile, devicenum,
                                                   verbose_init)
     else:#if devicefile == '/dev/sequencer':
         if devicefile != '/dev/sequencer':
@@ -108,6 +131,7 @@ def initialise_devicefile(devicefile, devicenum=0, verbose_init=0):
         import solfege.soundcard.oss_sequencer
         synth = solfege.soundcard.oss_sequencer.OSSSequencerSynth(devicefile, devicenum,
                                                 verbose_init)
+    solfege.mpd.track.set_patch_delay = cfg.get_int("app/set_patch_delay")
 
 def initialise_using_fake_synth(verbose_init=None):
     global synth
@@ -133,7 +157,7 @@ def end_export():
 instrument_sections = (
     'piano',
     'cromatic percussion',
-    'organ', 
+    'organ',
     'guitar',
     'bass',
     'strings',
